@@ -14,7 +14,7 @@ our %EXPORT_TAGS = ( 'all' => [ qw( add_image query_id loaddb savedb cleardb
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 our @EXPORT = qw( );
 
-our $VERSION = '0.01';
+our $VERSION = '0.04';
 
 require XSLoader;
 XSLoader::load('Image::Seek', $VERSION);
@@ -23,30 +23,45 @@ XSLoader::load('Image::Seek', $VERSION);
 
 Image::Seek - A port of ImgSeek to Perl
 
-=head1 DESCRIPTION
+=begin html
+
+<a href="https://travis-ci.org/wollmers/Image-Seek"><img src="https://travis-ci.org/wollmers/LCS.png" alt="Image-Seek"></a>
+<a href='https://coveralls.io/r/wollmers/Image-Seek?branch=master'><img src='https://coveralls.io/repos/wollmers/Image-Seek/badge.png?branch=master' alt='Coverage Status' /></a>
+<a href='http://cpants.cpanauthors.org/dist/Image-Seek'><img src='http://cpants.cpanauthors.org/dist/Image-Seek.png' alt='Kwalitee Score' /></a>
+<a href="http://badge.fury.io/pl/Image-Seek"><img src="https://badge.fury.io/pl/Image-Seek.svg" alt="CPAN version" height="18"></a>
+
+=end html
+
+=head1 SYNOPSIS
 
     use Image::Seek qw(loaddb add_image query_id savedb);
 
     loaddb("haar.db");
 
     # EITHER
+    my $img = GD::Image->newFromJpeg("photo-216.jpg", 1);
+
+    # OR
     my $img = Imager->new();
     $img->open(file => "photo-216.jpg");
+
     # OR
     my $img = Image::Imlib2->load("photo-216.jpg");
 
     # Then...
     add_image($img, 216);
-savedb("haar.db");
+    savedb("haar.db");
 
     my @results = query_id(216); # What looks like this photo?
 
+    remove_id(216); # Just remove id from database.
+
 =head1 DESCRIPTION
 
 ImgSeek (http://www.imgseek.net/) is an implementation of Haar wavelet
 decomposition techniques to find similar pictures in a library. This
 module is port of the ImgSeek library to Perl's XS. It can deal with
-image objects produced by the C<Imager> and C<Image::Imlib2> libraries.
+image objects produced by the C<Imager>, C<Image::Imlib2> and C<GD> libraries.
 
 =head1 EXPORT
 
@@ -74,6 +89,10 @@ C<$id>. This will compute the Haar transformation for a 128x128
 thumbnail of the image, and then store its norms into a database in
 memory.
 
+=head2 remove_id($id)
+
+remove id from database, and you should C<savedb> to save the changed database.
+
 =head2 query_id($id[, $results))
 
 This queries the internal database for pictures which are "like" number
@@ -102,16 +121,33 @@ sub add_image {
     my ($image, $id) = @_;
     if (UNIVERSAL::isa($image, "Imager"))        { goto &add_image_imager }
     if (UNIVERSAL::isa($image, "Image::Imlib2")) { goto &add_image_imlib2 }
+    if (UNIVERSAL::isa($image, "GD::Image"))     { goto &add_image_gd }
     croak "Don't know what sort of image $image is";
 }
 
+sub add_image_gd {
+    my ($img, $id) = @_;
+    my ($reds, $blues, $greens);
+
+    my $thumb = new GD::Image(128,128,1);
+    $thumb->copyResized($img,0,0,0,0,128,128,$img->width ,$img->height);
+
+    for my $y (0..127) {
+        for my $x (0..127) {
+            my ($r, $g, $b) = $thumb->rgb($thumb->getPixel($x,$y));
+            $reds .= chr($r); $blues .= chr($b); $greens .= chr($g);
+        }
+    }
+    addImage($id, $reds, $greens, $blues);
+}
+
 sub add_image_imager {
     my ($img, $id) = @_;
     my ($reds, $blues, $greens);
-    require Imager;
+
     my $thumb = $img->scaleX(pixels => 128)->scaleY(pixels => 128);
     for my $y (0..127) {
-        my @cols = $thumb->getscanline(y => $y);
+        my @cols = $thumb->getscanline('y' => $y);
         for (@cols) {
             my ($r, $g, $b) = $_->rgba;
             $reds .= chr($r); $blues .= chr($b); $greens .= chr($g);
@@ -120,12 +156,10 @@ sub add_image_imager {
     addImage($id, $reds, $greens, $blues);
 }
 
-use Digest::MD5 ("md5_hex");
-
 sub add_image_imlib2 {
     my ($img, $id) = @_;
     my ($reds, $blues, $greens);
-    require Image::Imlib2;
+
     my $thumb = $img->create_scaled_image(128,128);
     for my $y (0..127) {
         for my $x (0..127) {
@@ -146,6 +180,11 @@ sub query_id {
     @rv;
 }
 
+sub remove_id {
+    my $id = shift;
+    removeID($id);
+}
+
 1;
 __END__
 
@@ -154,16 +193,32 @@ __END__
 
 http://www.imgseek.net/
 
+=head1 SOURCE REPOSITORY
+
+L<http://github.com/wollmers/Image-Seek>
+
+=head1 MAINTAINER
+
+Helmut Wollmersdorfer E<lt>helmut.wollmersdorfer@gmail.comE<gt>
+
+=begin html
+
+<a href='http://cpants.cpanauthors.org/author/wollmers'><img src='http://cpants.cpanauthors.org/author/wollmers.png' alt='Kwalitee Score' /></a>
+
+=end html
+
 =head1 AUTHOR
 
 Simon Cozens, E<lt>simon@cpan.org<gt>
+Lilo Huang, E<lt>kenwu@cpan.orgE<gt>
+Helmut Wollmersdorfer, E<lt>helmut.wollmersdorfer@gmail.comE<gt>
 
-All the clever bits were written by Ricardo Niederberger Cabral; I just
+All the clever bits were written by Ricardo Niederberger Cabral; Simon Cozens just
 mangled them to wrap Perl around them.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2005 by Simon Cozens
+Copyright (C) 2005 by Simon Cozens, 2008 by Lilo Huang, 2015 Helmut Wollmersdorfer
 
 This library is free software; as it is a derivative work of imgseek,
 this library is distributed under the same terms (GPL) as imgseek.
